# coding: utf-8

"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import os

from patch_api.api_client import ApiClient


class TestEstimatesApi(unittest.TestCase):
    """EstimatesApi unit test stubs"""

    def setUp(self):
        api_client = ApiClient(api_key=os.environ.get("SANDBOX_API_KEY"))
        self.api = api_client.estimates  # noqa: E501

    def tearDown(self):
        self.api = None

    def test_create_and_retrieve_mass_estimate(self):
        """Test case for create_mass_estimate

        Create an estimate based on mass of CO2  # noqa: E501
        """
        mass_g = 100
        project_id = "pro_test_2b67b11a030b66e0a6dd61a56b49079a"
        estimate = self.api.create_mass_estimate(mass_g=mass_g, project_id=project_id)
        self.assertTrue(estimate)
        self.assertEqual(estimate.data.order.mass_g, mass_g)

        retrieved_estimate = self.api.retrieve_estimate(id=estimate.data.id)
        self.assertTrue(retrieved_estimate)

    def test_create_and_retrieve_flight_estimate(self):
        """Test case for create_flight_estimate

        Create an estimate based on the distance in meters flown by an airplane # noqa: E501
        """
        distance_m = 10000000
        estimate = self.api.create_flight_estimate(
            distance_m=distance_m, create_order=True
        )
        self.assertEqual(estimate.data.type, "flight")
        self.assertEqual(estimate.data.order.mass_g, 1031697)
        self.assertEqual(estimate.data.mass_g, 1031697)

        retrieved_estimate = self.api.retrieve_estimate(id=estimate.data.id)
        self.assertTrue(retrieved_estimate)

    def test_create_and_retrieve_shipping_estimate(self):
        """Test case for create_shipping_estimate

        Create an estimate based on the shipping distance, transportation method, and package mass  # noqa: E501
        """
        distance_m = 10000000
        package_mass_g = 1000
        transportation_method = "sea"
        estimate = self.api.create_shipping_estimate(
            distance_m=distance_m,
            package_mass_g=package_mass_g,
            transportation_method=transportation_method,
            create_order=False,
        )
        self.assertEqual(estimate.data.order, None)
        self.assertEqual(estimate.data.type, "shipping")
        self.assertEqual(estimate.data.mass_g, 373)

        retrieved_estimate = self.api.retrieve_estimate(id=estimate.data.id)
        self.assertTrue(retrieved_estimate)

    def test_create_and_retrieve_vehicle_estimate(self):
        """Test case for create_vehicle_estimate

        Create an estimate based on the vehicle distance, transportation method, and package mass  # noqa: E501
        """
        distance_m = 10000000
        make = "Toyota"
        model = "Corolla"
        year = 1995
        estimate = self.api.create_vehicle_estimate(
            distance_m=distance_m, model=model, make=make, year=year
        )
        self.assertEqual(estimate.data.type, "vehicle")
        self.assertEqual(estimate.data.mass_g, 5719674)

        retrieved_estimate = self.api.retrieve_estimate(id=estimate.data.id)
        self.assertTrue(retrieved_estimate)

    def test_create_and_retrieve_vehicle_estimate_best_match(self):
        """Test case for create_vehicle_estimate

        Create an estimate based on the vehicle with partial information  # noqa: E501
        """
        distance_m = 10000000
        make = "Toyota"
        model = "Corolla"
        estimate = self.api.create_vehicle_estimate(
            distance_m=distance_m, model=model, make=make
        )
        self.assertEqual(estimate.data.type, "vehicle")
        self.assertEqual(estimate.data.mass_g, 6499629)

        retrieved_estimate = self.api.retrieve_estimate(id=estimate.data.id)
        self.assertTrue(retrieved_estimate)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import os

from patch_api.api_client import ApiClient


class TestPreferencesApi(unittest.TestCase):
    """PreferencesApi unit test stubs"""

    def setUp(self):
        api_client = ApiClient(api_key=os.environ.get("SANDBOX_API_KEY"))
        self.api = api_client.preferences  # noqa: E501

    def tearDown(self):
        self.api = None

    def test_retrieve_preferences_and_preference(self):
        """Test case for retrieve_preferences and retrieve_preference

        creates a project preference  # noqa: E501
        """
        preferences = self.api.retrieve_preferences()
        self.assertTrue(isinstance(preferences.data, list))

        if len(preferences.data) > 0:
            preference_id = preferences.data[0].id
            preference = self.api.retrieve_preference(id=preference_id).data

            self.assertTrue(preference.allocation_percentage)
            self.assertTrue(preference.id)
            self.assertTrue(preference.project)

    def test_delete_and_create_preferences(self):
        """Test case for create_preference and delete_preference"""
        project_id = "pro_test_0de1a59eed9ff8474e09077ddb3714b2"
        preferences = self.api.retrieve_preferences()
        if len(preferences.data) > 0:
            preference_id = preferences.data[0].id
            deleted_preference = self.api.delete_preference(id=preference_id)

            self.assertTrue(deleted_preference)

        preference = self.api.create_preference(project_id=project_id).data
        self.assertTrue(preference.allocation_percentage)
        self.assertTrue(preference.id)
        self.assertTrue(preference.project)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import os

from patch_api.api_client import ApiClient


class TestOrdersApi(unittest.TestCase):
    """OrdersApi unit test stubs"""

    def setUp(self):
        api_client = ApiClient(api_key=os.environ.get("SANDBOX_API_KEY"))
        self.api = api_client.orders  # noqa: E501

    def tearDown(self):
        self.api = None

    def test_interactions_with_an_order(self):
        """Test case for create_order, retrieve_order"""

        """Create an order
        """
        order = self.api.create_order(mass_g=100)

        self.assertTrue(order)

        """Retrieve an order
        """
        order = self.api.create_order(mass_g=100)
        retrieved_order = self.api.retrieve_order(id=order.data.id)

        self.assertTrue(retrieved_order)

    def test_retrieve_orders(self):
        """Test case for retrieve_orders

        Retrieves a list of orders  # noqa: E501
        """
        orders = self.api.retrieve_orders().data
        self.assertTrue(isinstance(orders, list))

        if len(orders) > 1:
            retrieved_order = orders[0]

            self.assertTrue(retrieved_order.id)
            self.assertEqual(retrieved_order.production, False)
            self.assertEqual(retrieved_order.state, "placed")
            self.assertEqual(retrieved_order.metadata, {})
            self.assertTrue(isinstance(retrieved_order.allocations, list))


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from patch_api.models.allocation import Allocation
from patch_api.models.error_response import ErrorResponse
from patch_api.models.estimate import Estimate
from patch_api.models.estimate_list_response import EstimateListResponse
from patch_api.models.estimate_response import EstimateResponse
from patch_api.models.meta_index_object import MetaIndexObject
from patch_api.models.order import Order
from patch_api.models.order_list_response import OrderListResponse
from patch_api.models.order_response import OrderResponse
from patch_api.models.photo import Photo
from patch_api.models.preference import Preference
from patch_api.models.preference_list_response import PreferenceListResponse
from patch_api.models.preference_response import PreferenceResponse
from patch_api.models.project import Project
from patch_api.models.project_list_response import ProjectListResponse
from patch_api.models.project_response import ProjectResponse
from patch_api.models.standard import Standard



# coding: utf-8

"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from patch_api.configuration import Configuration


class Preference(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"id": "str", "allocation_percentage": "int", "project": "Project"}

    attribute_map = {
        "id": "id",
        "allocation_percentage": "allocation_percentage",
        "project": "project",
    }

    def __init__(
        self,
        id=None,
        allocation_percentage=None,
        project=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Preference - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._allocation_percentage = None
        self._project = None
        self.discriminator = None

        self.id = id
        self.allocation_percentage = allocation_percentage
        self.project = project

    @property
    def id(self):
        """Gets the id of this Preference.  # noqa: E501

        A unique uid for the record. UIDs will be prepended by pre_prod or pre_test depending on the mode it was created in.  # noqa: E501

        :return: The id of this Preference.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Preference.

        A unique uid for the record. UIDs will be prepended by pre_prod or pre_test depending on the mode it was created in.  # noqa: E501

        :param id: The id of this Preference.  # noqa: E501
        :type: str
        """
        if (
            self.local_vars_configuration.client_side_validation and id is None
        ):  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def allocation_percentage(self):
        """Gets the allocation_percentage of this Preference.  # noqa: E501

        Percentage of total purchased offsets that should go to a project. Default is 100%.  # noqa: E501

        :return: The allocation_percentage of this Preference.  # noqa: E501
        :rtype: int
        """
        return self._allocation_percentage

    @allocation_percentage.setter
    def allocation_percentage(self, allocation_percentage):
        """Sets the allocation_percentage of this Preference.

        Percentage of total purchased offsets that should go to a project. Default is 100%.  # noqa: E501

        :param allocation_percentage: The allocation_percentage of this Preference.  # noqa: E501
        :type: int
        """
        if (
            self.local_vars_configuration.client_side_validation
            and allocation_percentage is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `allocation_percentage`, must not be `None`"
            )  # noqa: E501

        self._allocation_percentage = allocation_percentage

    @property
    def project(self):
        """Gets the project of this Preference.  # noqa: E501

        An object returning the Project record this Preference is associated with. See the [Project section](/?id=projects) for the full schema.  # noqa: E501

        :return: The project of this Preference.  # noqa: E501
        :rtype: Project
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Preference.

        An object returning the Project record this Preference is associated with. See the [Project section](/?id=projects) for the full schema.  # noqa: E501

        :param project: The project of this Preference.  # noqa: E501
        :type: Project
        """
        if (
            self.local_vars_configuration.client_side_validation and project is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `project`, must not be `None`"
            )  # noqa: E501

        self._project = project

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Preference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Preference):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from patch_api.configuration import Configuration


class MetaIndexObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"prev_page": "int", "next_page": "int"}

    attribute_map = {"prev_page": "prev_page", "next_page": "next_page"}

    def __init__(
        self, prev_page=None, next_page=None, local_vars_configuration=None
    ):  # noqa: E501
        """MetaIndexObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._prev_page = None
        self._next_page = None
        self.discriminator = None

        self.prev_page = prev_page
        self.next_page = next_page

    @property
    def prev_page(self):
        """Gets the prev_page of this MetaIndexObject.  # noqa: E501


        :return: The prev_page of this MetaIndexObject.  # noqa: E501
        :rtype: int
        """
        return self._prev_page

    @prev_page.setter
    def prev_page(self, prev_page):
        """Sets the prev_page of this MetaIndexObject.


        :param prev_page: The prev_page of this MetaIndexObject.  # noqa: E501
        :type: int
        """

        self._prev_page = prev_page

    @property
    def next_page(self):
        """Gets the next_page of this MetaIndexObject.  # noqa: E501


        :return: The next_page of this MetaIndexObject.  # noqa: E501
        :rtype: int
        """
        return self._next_page

    @next_page.setter
    def next_page(self, next_page):
        """Sets the next_page of this MetaIndexObject.


        :param next_page: The next_page of this MetaIndexObject.  # noqa: E501
        :type: int
        """

        self._next_page = next_page

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetaIndexObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MetaIndexObject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Patch API V1

    The core API used to integrate with Patch's service  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: developers@usepatch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from patch_api.exceptions import ApiTypeError, ApiValueError


class ProjectsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    ALLOWED_QUERY_PARAMS = [
        "mass_g",
        "price_cents_usd",
        "project_id",
        "page",
        "distance_m",
        "transportation_method",
        "package_mass_g",
        "create_order",
        "model",
        "make",
        "year",
    ]

    def __init__(self, api_client=None):
        self.api_client = api_client

    def retrieve_project(self, id={}, **kwargs):  # noqa: E501
        """Retrieves a project  # noqa: E501

        Retrieves a project available on Patch's platform.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_project(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ProjectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.retrieve_project_with_http_info(id, **kwargs)  # noqa: E501

    def retrieve_project_with_http_info(self, id, **kwargs):  # noqa: E501
        """Retrieves a project  # noqa: E501

        Retrieves a project available on Patch's platform.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_project_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ProjectResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")
        all_params.append("mass_g")
        all_params.append("price_cents_usd")
        all_params.append("project_id")
        all_params.append("metadata")
        all_params.append("distance_m")
        all_params.append("transportation_method")
        all_params.append("package_mass_g")
        all_params.append("create_order")
        all_params.append("make")
        all_params.append("model")
        all_params.append("year")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_project" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'id' is set
        if "id" not in local_var_params or local_var_params["id"] is None:
            raise ApiValueError(
                "Missing the required parameter `id` when calling `retrieve_project`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "id" in local_var_params:
            path_params["id"] = local_var_params["id"]  # noqa: E501

        query_params = []
        for key in kwargs:
            query_params.append([key, kwargs.get(key)])

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["bearer_auth"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/projects/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ProjectResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def retrieve_projects(self, **kwargs):  # noqa: E501
        """Retrieves a list of projects  # noqa: E501

        Retrieves a list of projects available for purchase on Patch's platform.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_projects(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page:
        :param str country:
        :param str type:
        :param int minimum_available_mass:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ProjectListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.retrieve_projects_with_http_info(**kwargs)  # noqa: E501

    def retrieve_projects_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieves a list of projects  # noqa: E501

        Retrieves a list of projects available for purchase on Patch's platform.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_projects_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int page:
        :param str country:
        :param str type:
        :param int minimum_available_mass:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ProjectListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["page", "country", "type", "minimum_available_mass"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")
        all_params.append("mass_g")
        all_params.append("price_cents_usd")
        all_params.append("project_id")
        all_params.append("metadata")
        all_params.append("distance_m")
        all_params.append("transportation_method")
        all_params.append("package_mass_g")
        all_params.append("create_order")
        all_params.append("make")
        all_params.append("model")
        all_params.append("year")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_projects" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        for key in kwargs:
            query_params.append([key, kwargs.get(key)])
        if "page" in local_var_params:
            query_params.append(("page", local_var_params["page"]))  # noqa: E501
        if "country" in local_var_params:
            query_params.append(("country", local_var_params["country"]))  # noqa: E501
        if "type" in local_var_params:
            query_params.append(("type", local_var_params["type"]))  # noqa: E501
        if "minimum_available_mass" in local_var_params:
            query_params.append(
                ("minimum_available_mass", local_var_params["minimum_available_mass"])
            )  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["bearer_auth"]  # noqa: E501

        return self.api_client.call_api(
            "/v1/projects",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ProjectListResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )
